========== Claun help ========== Framework entity ================== :Author: Jiri Chadima :Version: 2012/04/18 Description ----------- Framework configuration is stored in **couchDB** as a JSON document. By using the administration form, you can let the server create the document for you. A full example framework document can be seen in the framework.json_ file. Every framework configuration has its own document. Some fields in the document are generated by the server. They are described in the appropriate module. Form fields ---------------- The fields in the **application** form are: - **Framework Name** - You can name the framework whatever you want, but remember that the name is used during the startup process to automatically detect the appropriate builder and runner. You should choose lowercase names with no spaces and special characters. (mandatory) - **Name** - Name of the configuration. Same rules as for the framework name apply(mandatory) - **Parameters** - JSON string with list of key-value records. It is used to generate framework configuration and is framework dependent. Example configurations ----------------------------- Take the contents of the **parameters** attribute (with the parentheses) and paste it into the Parameters field. :CAVELib: - Framework name - cavelib - Example doc - framework.json_ .. _framework.json: framework.json .. _`Frameworks and Controllers documentation`: /distribappcontrol/admin/help/index.html